#
# spec file for package akka
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedreltag %{nil}
%global namedversion %{version}%{?namedreltag}
%global scala_short_version 2.13
Name:           akka
Version:        2.8.5
Release:        2.1
Summary:        Scalable real-time transaction processing
License:        Apache-2.0
URL:            https://akka.io/
Source0:        %{name}-%{version}.tar.xz
# Default use sbt
Source1:        akka-build.xml
# Build only these sub-modules, cause: unavailable build deps
# TODO  akka-camel akka-contrib akka-durable-mailboxes akka-persistence akka-samples akka-zeromq
Source2:        https://repo1.maven.org/maven2/com/typesafe/akka/akka-actor_%{scala_short_version}/%{namedversion}/akka-actor_%{scala_short_version}-%{namedversion}.pom
Source3:        https://repo1.maven.org/maven2/com/typesafe/akka/akka-cluster_%{scala_short_version}/%{namedversion}/akka-cluster_%{scala_short_version}-%{namedversion}.pom
Source4:        https://repo1.maven.org/maven2/com/typesafe/akka/akka-remote_%{scala_short_version}/%{namedversion}/akka-remote_%{scala_short_version}-%{namedversion}.pom
Source5:        https://repo1.maven.org/maven2/com/typesafe/akka/akka-slf4j_%{scala_short_version}/%{namedversion}/akka-slf4j_%{scala_short_version}-%{namedversion}.pom
BuildRequires:  ant
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  scala-ant
BuildRequires:  mvn(com.google.protobuf:protobuf-java)
# typesafe-config
BuildRequires:  mvn(com.typesafe:config)
BuildRequires:  mvn(io.netty:netty)
BuildRequires:  mvn(org.osgi:osgi.cmpn)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildRequires:  mvn(org.scala-lang:scala-compiler)
BuildRequires:  mvn(org.scala-lang:scala-library)
BuildRequires:  mvn(org.scala-stm:scala-stm_%{scala_short_version})
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.uncommons.maths:uncommons-maths)
# requires for akka-remote
BuildRequires:  protobuf-devel scala-java8-compat
BuildRequires:  sbt-boilerplate
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
Akka is a toolkit and run-time for building highly concurrent,
distributed, and fault tolerant event-driven applications on
the JVM.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q

cp -p %{SOURCE1} build.xml
sed -i "s|@VERSION@|%{namedversion}|" build.xml

rm -rf */src/main/scala-3 */src/main/scala-2.12

# spurious-executable-perm
chmod 644 LICENSE

%build

pushd akka-actor
mkdir -p src/main/gen-scala
for i in $(find src/main/boilerplate -name \*.scala.template); do
   sbt-boilerplate $i >src/main/gen-scala/$(basename $i .template);
done
cat <<EOF >src/main/gen-scala/Version.scala
package akka

object Version {
  val current: String = "%{vesion}"
}
EOF
echo "akka.version = \"%{version}\"" >src/main/resources/version.conf

mkdir -p target/classes
scalac -nobootcp -d target/classes -cp $(build-classpath scala typesafe-config) -target:8 \
    $(find src/main -name \*.scala -o -name \*.java | xargs)
javac -d target/classes -cp $(build-classpath scala typesafe-config):target/classes \
    -source 8 -target 8 -encoding utf-8 \
    $(find src/main -name \*.java | xargs)
jar \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 17}%{!?pkg_vcmp:0}
    --date="$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)" \
%endif
    --create --file=target/%{name}-actor.jar -C target/classes . -C src/main/resources .

mkdir -p target/apidocs
scaladoc -nobootcp -d target/apidocs -cp $(build-classpath scala typesafe-config) -target:8 \
    $(find src/main -name \*.scala -o -name \*.java | xargs)
popd

%{mvn_artifact} %{SOURCE2} akka-actor/target/%{name}-actor.jar

%install
%mvn_install -J akka-actor/target/apidocs

%files -f .mfiles
%license LICENSE
%doc CONTRIBUTING.md README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Thu Sep 19 2024 Fridrich Strba <fstrba@suse.com>
- Specify jar timestamp for reproducible builds
* Thu Oct 12 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.8.5
  * Changes of 2.8.5
    + backport: clear inflight DNS requests on failure to allow
    retries (#32110)
    + fix: DownSelfQuarantinedByRemote should not be triggered by
    harmless quarantine, #31095 (backport)
  * Changes of 2.8.4
    + feat: event writer
    + fix: discard ReceiveTimeout when timeout message is null
    + Add javadsl for Effect.delete() in durable state #32027
    + perf: streamline recursion in mapAsyncPartitioned #32031
    + Add short-circuit support in retry pattern #32035
    + test: harden PersistentActorRecoveryTimeoutSpec, #31624
  * Changes of 2.8.3
    + Update Scala to 2.12.18 & 2.13.11
    + feat: Include exception type in StatusReply toString when not
    text
    + str Add Flow contramap
    + fix: Better exception string in StatusReply
    + fix: AllocationStrategy in ShardedDaemonProcess
    + feat: Collocating shards with consistent hashing
    + perf: Scalable slice queries for many consumers
    + fix: Try to limit spin loop in TLSActor #29922
    + test: harden EventsBySliceFirehoseSpec, #31979
    + feat: Placeholder event representation for filtered journal
    events
    + feat: Query traits for using snapshots as starting point
  * Changes of 2.8.2
    + feat: Make it possible to define appVersion later
    + feat: More Serializer constructor alternatives
  * Changes of 2.8.1
    + feat: Make it possible to include tags in event envelope
    + feat: Typed envelope version of the eventsByPersistenceId
    queries
    + feat: Tagger that can look at state for event sourced
    behaviour
    + str Add onErrorComplete operator
    + fix: starting Sharding with separate Coordinator role, #31637
    + fix: Eager init of DistributedData extension from
    ExternalShardAllocationStrategy
    + fix: Refactor concurrency in AsyncDnsResolver
    + Various and sundry async-dns improvements
    + str Add startAfterNrOfConsumers to BroadcastHub
    + str Implement Source.never as a dedicated GraphStage
  * New features of 2.8.0
    + Expiry of CRDT entries, #27683
    + Wildcard subscription of ddata changes
    + Add color to LogCapturing #31689
    + feat: Throttle keep alive messages of ShardedDaemonProcess
    + feat: API for dynamic scaling of Sharded daemon process
    instances
    + feat: More fine grained control of stream error logging
    + mapAsyncPartitioned stream operator
    + Auto-select SRV lookup for the name lookup if entry looks
    like a srv name
- Removed patches:
  * akka-2.3.0-typesafe-config-1.3.0.patch
  * akka-2.3.16-typesafe-config-1.4.1.patch
    + not needed with this version
* Sat Apr 30 2022 Fridrich Strba <fstrba@suse.com>
- Build against io.netty:netty, since the compat versions do not
  exist any more
* Fri Apr 29 2022 Fridrich Strba <fstrba@suse.com>
- Use %%%%mvn_artifact and %%%%mvn_install instead of %%%%add_maven_depmap
  * Allow resolution against netty3 that uses compatibility versions
* Thu Apr 28 2022 Dirk Müller <dmueller@suse.com>
- use https url
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
- Removed patch:
  * akka-2.3.0-encoding.patch
    + the change is directly integrated in the akka-build.xml file
* Tue Apr 20 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * akka-2.3.16-typesafe-config-1.4.1.patch
    + conditionlally applied patch to enable build against
    typesafe-config >= 1.4.1
* Mon Apr 19 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * akka-2.3.0-typesafe-config-1.3.0.patch
    + conditionally applied patch to be able to build against
    typesafe-config >= 1.3
* Thu Apr  9 2020 Fridrich Strba <fstrba@suse.com>
- Don't build against eclipse-osgi, but again osgi-core and
  osgi-compendium packages in order to prevent a fat dependency
  for a feature that is well served by lighter packages
* Wed Mar  4 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of akka 2.3.16
